@@ -414,10 +414,10 @@ class VLE:
             P_bubble, y_bubble = self._bubble_point.solve_Py(self._z, T)
             self._V = V 
             self._refresh_v(V, y_bubble)
-            P = flx.IQ_interpolation(self._V_at_P,
+            P = flx.IQ_interpolation(self._V_err_at_P,
                                      P_bubble, P_dew, 0, 1,
-                                     self._P, self._V,
-                                     self.P_tol, self.V_tol)
+                                     self._P, self.P_tol, self.V_tol,
+                                     (self._V,))
              
             # In case solver cannot reach the vapor fraction because
             # the composition does not converge at values that meets the
@@ -482,11 +482,11 @@ class VLE:
         self._refresh_v(V, y_bubble)
         F_mass = self._F_mass
         H_hat = H/F_mass
-        P = flx.IQ_interpolation(self._H_hat_at_P,
+        P = flx.IQ_interpolation(self._H_hat_err_at_P,
                         P_bubble, P_dew,
                         H_bubble/F_mass, H_dew/F_mass,
-                        self._P, H_hat,
-                        self.P_tol, self.H_hat_tol)
+                        self._P, self.P_tol, self.H_hat_tol,
+                        (H_hat,))
         self._P = self._thermal_condition.P = P   
         self._thermal_condition.T = T
     
@@ -517,10 +517,10 @@ class VLE:
             T_bubble, y_bubble = self._bubble_point.solve_Ty(self._z, P)
             self._refresh_v(V, y_bubble)
             self._V = V 
-            T = flx.IQ_interpolation(self._V_at_T,
+            T = flx.IQ_interpolation(self._V_err_at_T,
                                      T_bubble, T_dew, 0, 1,
-                                     self._T , V,
-                                     self.T_tol, self.V_tol)
+                                     self._T, self.T_tol, self.V_tol,
+                                     (V,))
             
             # In case solver cannot reach the vapor fraction because
             # the composition does not converge at values that meets the
@@ -590,11 +590,11 @@ class VLE:
         H_hat = H/F_mass
         H_hat_bubble = H_bubble/F_mass
         H_hat_dew = H_dew/F_mass
-        T = flx.IQ_interpolation(self._H_hat_at_T,
+        T = flx.IQ_interpolation(self._H_hat_err_at_T,
                                  T_bubble, T_dew, 
                                  H_hat_bubble, H_hat_dew,
-                                 self._T , H_hat,
-                                 self.T_tol, self.H_hat_tol)
+                                 self._T, self.T_tol, self.H_hat_tol,
+                                 (H_hat,))
         
         # Make sure enthalpy balance is correct
         self._T = thermal_condition.T = self.mixture.xsolve_T(
@@ -612,24 +612,23 @@ class VLE:
         else:
             self._v = y * self._F_mol_vle * V
     
-    def _H_hat_at_T(self, T):
+    def _H_hat_err_at_T(self, T, H_hat):
         self._vapor_mol[self._index] = self._solve_v(T, self._P)
         self._liquid_mol[self._index] = self._mol - self._v
         self._H_hat = self.mixture.xH(self._phase_data, T, self._P)/self._F_mass
-        return self._H_hat
+        return self._H_hat - H_hat
     
-    def _H_hat_at_P(self, P):
+    def _H_hat_err_at_P(self, P, H_hat):
         self._vapor_mol[self._index] = self._solve_v(self._T , P)
         self._liquid_mol[self._index] = self._mol - self._v
         self._H_hat = self.mixture.xH(self._phase_data, self._T, P)/self._F_mass
-        return self._H_hat
+        return self._H_hat - H_hat
     
-    def _V_at_P(self, P):
-        return self._solve_v(self._T , P).sum()/self._F_mol_vle
+    def _V_err_at_P(self, P, V):
+        return self._solve_v(self._T , P).sum()/self._F_mol_vle - V
     
-    def _V_at_T(self, T):
-        V = self._solve_v(T, self._P).sum()/self._F_mol_vle 
-        return V
+    def _V_err_at_T(self, T, V):
+        return self._solve_v(T, self._P).sum()/self._F_mol_vle  - V
     
     def _x_iter(self, x, Psat_over_P_phi):
         x = x/x.sum()
